@@ -145,8 +145,9 @@ qgis_configure <- function(quiet = FALSE, use_cached_data = FALSE) {
 
           # CACHE CONDITION: qgis_process is indeed available in the cached path
 
+          testopt <- getOption("qgisprocess.test_skip_path_availability_check")
           outcome <- try(qgis_run(path = cached_data$path), silent = TRUE)
-          if (inherits(outcome, "try-error")) {
+          if (inherits(outcome, "try-error") && !isTRUE(testopt)) {
             if (quiet) packageStartupMessage()
             packageStartupMessage(
               glue(
@@ -162,23 +163,15 @@ qgis_configure <- function(quiet = FALSE, use_cached_data = FALSE) {
           # environment variable/option to automatically switch to a newer
           # available QGIS version
           if (is_windows() || is_macos()) {
-            opt <- getOption(
-              "qgisprocess.detect_newer_qgis",
-              Sys.getenv("R_QGISPROCESS_DETECT_NEWER_QGIS")
+            opt <- resolve_flag_opt(
+              option_name = "qgisprocess.detect_newer_qgis",
+              envvar_name = "R_QGISPROCESS_DETECT_NEWER_QGIS"
             )
-            assert_that(
-              assertthat::is.flag(opt) ||
-                (assertthat::is.string(opt) && opt %in% c("", "TRUE", "FALSE", "true", "false")),
-              msg = "Option 'qgisprocess.detect_newer_qgis' must be 'TRUE' or 'FALSE'."
-            )
-            if (identical(opt, "")) opt <- NA
-            opt || grepl("TRUE|true", opt)
-
             first_qgis <- qgis_detect_paths()[1]
             newer_available <- !is.na(extract_version_from_paths(first_qgis)) &&
               !identical(cached_data$path, first_qgis)
 
-            if (isTRUE(opt) && isTRUE(newer_available) && interactive()) {
+            if (opt && isTRUE(newer_available) && rlang::is_interactive()) {
               packageStartupMessage()
               packageStartupMessage(glue(
                 "A newer QGIS installation seems to be available: ",
@@ -186,7 +179,8 @@ qgis_configure <- function(quiet = FALSE, use_cached_data = FALSE) {
               ))
               answer <- ""
               while (!grepl("^[Yy](?:[Ee][Ss])?$|^[Nn](?:[Oo])?$", answer)) {
-                answer <- readline("Do you want to try it and rebuild the cache? (y/n) ")
+                answer <- getOption("qgisprocess.test_try_new_qgis") %||%
+                  readline("Do you want to try it and rebuild the cache? (y/n) ")
               }
               if (grepl("^[Yy]", answer)) {
                 newer_ok <- FALSE
@@ -247,6 +241,48 @@ qgis_configure <- function(quiet = FALSE, use_cached_data = FALSE) {
 
           if (!quiet) message(glue("QGIS versions match! ({qversion})"))
 
+          # CACHE CONDITION: the use_json_output element does not contradict the environment
+          # variable/option for the output or input method (JSON vs legacy)
+
+          # Since we want library(qgisprocess) to take into account
+          # pre-existing settings for the JSON output, we must reconfigure if
+          # it is not consistent with  qgis_using_json_output().
+
+          # There is good reason to cache 'use_json_output': the value of
+          # qgis_algorithms() and qgis_plugins() is different when populating
+          # it with or without the --json flag.
+
+          opt <- readopt_json_output()
+          qversion_short <- strsplit(qversion, "-")[[1]][1]
+
+          if (
+            ( ## conflict with explicit json_output AND json_input setting?
+              !identical(opt, "") &&
+                # resolving conflicts with explicit JSON INput setting:
+                !identical(
+                  resolve_explicit_json_output(
+                    json_output_setting = opt,
+                    qgis_version = qversion_short
+                  ),
+                  cached_data$use_json_output
+                )) ||
+              ( ## conflict with explicit json_INput set as TRUE?
+                identical(opt, "") &&
+                  json_input_set_and_acceptable(qversion_short) &&
+                  isFALSE(cached_data$use_json_output)
+              )
+          ) {
+            if (quiet) packageStartupMessage()
+            packageStartupMessage(glue(
+              "The outcome of user settings for using JSON input/output ",
+              "contradict the 'use_json_output' cache value ",
+              "({cached_data$use_json_output}).\n",
+              "Hence rebuilding cache to reflect this change ..."
+            ))
+            qgis_reconfigure(cache_data_file = cache_data_file, quiet = quiet)
+            return(invisible(has_qgis()))
+          }
+
           # CACHE CONDITION: the cached QGIS plugins equal the ones reported by
           # qgis_process, including their state
 
@@ -256,9 +292,11 @@ qgis_configure <- function(quiet = FALSE, use_cached_data = FALSE) {
 
           qgisprocess_cache$path <- cached_data$path
           qgisprocess_cache$use_json_output <- cached_data$use_json_output
+          qgisprocess_cache$version <- cached_data$version
           qplugins <- qgis_query_plugins(quiet = quiet)
           qgisprocess_cache$path <- NULL
           qgisprocess_cache$use_json_output <- NULL
+          qgisprocess_cache$version <- NULL
 
           if (!identical(qplugins, cached_data$plugins)) {
             if (quiet) packageStartupMessage()
@@ -438,7 +476,7 @@ qgis_reconfigure <- function(cache_data_file, quiet = FALSE) {
 message_inspect_cache <- function() {
   message(
     "Use qgis_algorithms(), qgis_providers(), qgis_plugins(), ",
-    "qgis_using_json_output(),\nqgis_path() and qgis_version() ",
+    "qgis_path() and\nqgis_version() ",
     "to inspect the cache environment."
   )
 }
